@@ -74,10 +74,20 @@
  * mask is 0xFFFF0000.
  */
 #define ABI_ANSIC_VERSION	SET_ABI_VERSION(1, 4)
-#define ABI_VIDEODRV_VERSION	SET_ABI_VERSION(28, 0)
+
+/* XXX This is a compile-time option that changes abi XXX */
+/* TODO: Remove this toggle in 26.0 */
+#ifdef CONFIG_LEGACY_NVIDIA_PADDING
+#define ABI_VIDEODRV_VERSION	SET_ABI_VERSION(28, 1)
+#else
+#define ABI_VIDEODRV_VERSION    SET_ABI_VERSION(28, 0)
+#endif
 #define ABI_XINPUT_VERSION	SET_ABI_VERSION(26, 0)
 #define ABI_EXTENSION_VERSION	SET_ABI_VERSION(11, 0)
 
+/* hack to get both modern and ancient nvidia DDX drivers to work at the same time */
+#define ABI_NVIDIA_VERSION      SET_ABI_VERSION(25, 2)
+
 #define MODINFOSTRING1	0xef23fdc5
 #define MODINFOSTRING2	0x10dc023a
 
@@ -167,56 +177,4 @@ typedef struct {
     ModuleTearDownProc teardown;
 } XF86ModuleData;
 
-/*
- * declare module version info structure for an input driver module
- */
-#define XF86_MODULE_VERSION_INPUT(_name, _major, _minor, _patchlevel)   \
-    static XF86ModuleVersionInfo modVersion = { \
-        .modname      = _name,                  \
-        .vendor       = MODULEVENDORSTRING,     \
-        ._modinfo1_   = MODINFOSTRING1,         \
-        ._modinfo2_   = MODINFOSTRING2,         \
-        .xf86version  = XORG_VERSION_CURRENT,   \
-        .majorversion = _major,                 \
-        .minorversion = _minor,                 \
-        .patchlevel   = _patchlevel,            \
-        .abiclass     = ABI_CLASS_XINPUT,       \
-        .abiversion   = ABI_XINPUT_VERSION,     \
-        .moduleclass  = MOD_CLASS_XINPUT,       \
-    };
-
-/*
- * declare module version info structure for an video driver module
- */
-#define XF86_MODULE_VERSION_VIDEO(_name, _major, _minor, _patchlevel)   \
-    static XF86ModuleVersionInfo modVersion = { \
-        .modname      = _name,                  \
-        .vendor       = MODULEVENDORSTRING,     \
-        ._modinfo1_   = MODINFOSTRING1,         \
-        ._modinfo2_   = MODINFOSTRING2,         \
-        .xf86version  = XORG_VERSION_CURRENT,   \
-        .majorversion = _major,                 \
-        .minorversion = _minor,                 \
-        .patchlevel   = _patchlevel,            \
-        .abiclass     = ABI_CLASS_VIDEODRV,     \
-        .abiversion   = ABI_VIDEODRV_VERSION,   \
-        .moduleclass  = MOD_CLASS_VIDEODRV,     \
-    };
-
-#define XF86_MODULE_DATA_INPUT(_modname, _setup, _teardown, _name, _major, _minor, _patchlevel) \
-    XF86_MODULE_VERSION_INPUT(_name, _major, _minor, _patchlevel) \
-    _X_EXPORT XF86ModuleData _modname##ModuleData = { \
-        .vers = &modVersion, \
-        .setup = _setup, \
-        .teardown = _teardown, \
-    };
-
-#define XF86_MODULE_DATA_VIDEO(_modname, _setup, _teardown, _name, _major, _minor, _patchlevel) \
-    XF86_MODULE_VERSION_VIDEO(_name, _major, _minor, _patchlevel) \
-    _X_EXPORT XF86ModuleData _modname##ModuleData = { \
-        .vers = &modVersion, \
-        .setup = _setup, \
-        .teardown = _teardown, \
-    };
-
-#endif /* _XF86MODULE_H */
+#endif                          /* _XF86STR_H */
